# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .endpoint import *
from .get_endpoints import *
from .get_resolver_zones import *
from .get_rules import *
from .get_service import *
from .get_zone_records import *
from .get_zones import *
from .rule import *
from .rule_attachment import *
from .user_vpc_authorization import *
from .zone import *
from .zone_attachment import *
from .zone_record import *
from ._inputs import *
from . import outputs
